
.. _tools:

******************
Command-line tools
******************

G5print
-------

.. argparse::
    :module: GooseHDF5
    :func: _G5print_parser
    :prog: G5print

G5list
-------

.. argparse::
    :module: GooseHDF5
    :func: _G5list_parser
    :prog: G5list

G5compare
---------

.. argparse::
    :module: GooseHDF5
    :func: _G5compare_parser
    :prog: G5compare

G5check
-------

.. automodule:: GooseHDF5.cli.G5check

G5repair
--------

.. automodule:: GooseHDF5.cli.G5repair

G5repack
--------

.. automodule:: GooseHDF5.cli.G5repack
